
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.019.
use strict;
use warnings;

use Module::Build 0.3601;
use lib qw{inc}; use My::ModuleBuild;

my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Git::Wrapper" => 0,
    "Module::Build" => "0.3601",
    "Sort::Versions" => 0
  },
  "dist_abstract" => "Convert cpan distribution from BackPAN to a git repository",
  "dist_author" => [
    "Graham Ollis <plicease\@cpan.org>"
  ],
  "dist_name" => "App-cpangitify",
  "dist_version" => "0.09",
  "license" => "perl",
  "module_name" => "App::cpangitify",
  "recommends" => {
    "JSON::XS" => 0,
    "PerlX::Maybe::XS" => 0
  },
  "recursive_test_files" => 1,
  "requires" => {
    "Archive::Extract" => 0,
    "BackPAN::Index" => "0.41",
    "File::Copy::Recursive" => 0,
    "File::chdir" => 0,
    "Git::Wrapper" => 0,
    "IPC::System::Simple" => 0,
    "JSON" => 0,
    "LWP::UserAgent" => 0,
    "Path::Class" => "0.26",
    "PerlX::Maybe" => "0.003",
    "URI" => 0,
    "autodie" => 0,
    "perl" => "v5.10.0"
  },
  "script_files" => [
    "bin/cpangitify"
  ],
  "test_requires" => {
    "Capture::Tiny" => 0,
    "File::HomeDir" => "0.91",
    "Test::More" => "0.94",
    "URI::file" => 0
  }
);


my %fallback_build_requires = (
  "Capture::Tiny" => 0,
  "File::HomeDir" => "0.91",
  "Module::Build" => "0.3601",
  "Test::More" => "0.94",
  "URI::file" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = My::ModuleBuild->new(%module_build_args);

$build->create_build_script;
